package com.qmth.themis.exam.api;

import java.util.HashMap;
import java.util.Map;

import javax.annotation.Resource;

import org.springframework.transaction.annotation.Transactional;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import com.qmth.themis.business.bean.exam.FaceVerifyBean;
import com.qmth.themis.business.enums.MqEnum;
import com.qmth.themis.business.service.TOeFaceVerifyHistoryService;
import com.qmth.themis.common.util.Result;
import com.qmth.themis.common.util.ResultUtil;
import com.qmth.themis.mq.dto.MqDto;
import com.qmth.themis.mq.enums.MqTagEnum;
import com.qmth.themis.mq.enums.MqTopicEnum;
import com.qmth.themis.mq.service.MqDtoService;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import io.swagger.annotations.ApiResponse;
import io.swagger.annotations.ApiResponses;

/**
 * 人脸验证
 * 
 * @Description:
 * @Author: xiatian
 * @Date: 2020-07-31
 */
@Api(tags = "人脸验证")
@RestController
@RequestMapping("/${prefix.url.exam}/face")
public class TEFaceController {

	@Resource
	TOeFaceVerifyHistoryService faceVerifyHistoryService;
	
	@Resource
	MqDtoService mqDtoService;

	@ApiOperation(value = "人脸验证结果")
	@RequestMapping(value = "/verify", method = RequestMethod.POST)
	@ApiResponses({ @ApiResponse(code = 200, message = "人脸验证信息") })
	@Transactional
	public Result verify(@ApiParam(value = "考试记录ID", required = true) @RequestParam Long recordId,
			@ApiParam(value = "FIRST_START:首次开考, RESUME_START:断点恢复, IN_PROCESS:过程中", required = true) @RequestParam String type,
			@ApiParam(value = "照片文件URL", required = true) @RequestParam String photoUrl,
			@ApiParam(value = "人脸数量", required = true) @RequestParam Integer faceCount,
			@ApiParam(value = "相似度分数", required = true) @RequestParam Double similarity,
			@ApiParam(value = "真实性结果", required = true) @RequestParam Double realness,
			@ApiParam(value = "验证时间", required = true) @RequestParam Long time,
			@ApiParam(value = "NONE: 无异常 FACE_COUNT_ERROR: 人脸数量异常 FACE_COMPARE_ERROR: 人脸比对异常 EYE_CLOSE_ERROR: 闭眼检测异常", required = true) @RequestParam String exception) {
		FaceVerifyBean ret=faceVerifyHistoryService.verify(recordId,type,photoUrl,faceCount,similarity,realness,time,exception);
		Map<String, Object> transMap = new HashMap<String, Object>();
		transMap.put("id", ret.getId());
		transMap.put("recordId", recordId);
		transMap.put("type", type);
        transMap.put("photoUrl", photoUrl);
        transMap.put("faceCount", faceCount);
        transMap.put("similarity", similarity);
        transMap.put("realness", realness);
        transMap.put("time", time);
        transMap.put("exception", exception);
        //mq发送消息start
        MqDto mqDto = new MqDto(MqTopicEnum.themisTopic.getCode(), MqTagEnum.faceVerifySave.name(), transMap, MqEnum.EXAM, null, null);
        mqDtoService.assembleSendOneWayMsg(mqDto);
		return ResultUtil.ok(ret);
	}

}
